from __future__ import annotations

from licensecheck.types import License as L

spdxToLicense = {
	"0BSD": L.BSD,
	"BSD ZERO CLAUSE LICENSE": L.BSD,
	"AAL": L.UNKNOWN,
	"ATTRIBUTION ASSURANCE LICENSE": L.UNKNOWN,
	"AFL-1.1": L.ACADEMIC_FREE,
	"ACADEMIC FREE LICENSE V1.1": L.ACADEMIC_FREE,
	"AFL-1.2": L.ACADEMIC_FREE,
	"ACADEMIC FREE LICENSE V1.2": L.ACADEMIC_FREE,
	"AFL-2.0": L.ACADEMIC_FREE,
	"ACADEMIC FREE LICENSE V2.0": L.ACADEMIC_FREE,
	"AFL-2.1": L.ACADEMIC_FREE,
	"ACADEMIC FREE LICENSE V2.1": L.ACADEMIC_FREE,
	"AFL-3.0": L.ACADEMIC_FREE,
	"ACADEMIC FREE LICENSE V3.0": L.ACADEMIC_FREE,
	"AGPL-3.0": L.AGPL_3_PLUS,
	"GNU AFFERO GENERAL PUBLIC LICENSE V3.0": L.AGPL_3_PLUS,
	"AGPL-3.0-ONLY": L.AGPL_3_PLUS,
	"GNU AFFERO GENERAL PUBLIC LICENSE V3.0 ONLY": L.AGPL_3_PLUS,
	"AGPL-3.0-OR-LATER": L.AGPL_3_PLUS,
	"GNU AFFERO GENERAL PUBLIC LICENSE V3.0 OR LATER": L.AGPL_3_PLUS,
	"APACHE-1.1": L.APACHE,
	"APACHE LICENSE 1.1": L.APACHE,
	"APACHE-2.0": L.APACHE,
	"APACHE LICENSE 2.0": L.APACHE,
	"APL-1.0": L.UNKNOWN,
	"ADAPTIVE PUBLIC LICENSE 1.0": L.UNKNOWN,
	"APSL-1.0": L.UNKNOWN,
	"APPLE PUBLIC SOURCE LICENSE 1.0": L.UNKNOWN,
	"APSL-1.1": L.UNKNOWN,
	"APPLE PUBLIC SOURCE LICENSE 1.1": L.UNKNOWN,
	"APSL-1.2": L.UNKNOWN,
	"APPLE PUBLIC SOURCE LICENSE 1.2": L.UNKNOWN,
	"APSL-2.0": L.UNKNOWN,
	"APPLE PUBLIC SOURCE LICENSE 2.0": L.UNKNOWN,
	"ARTISTIC-1.0": L.UNKNOWN,
	"ARTISTIC LICENSE 1.0": L.UNKNOWN,
	"ARTISTIC-1.0-CL8": L.UNKNOWN,
	"ARTISTIC LICENSE 1.0 W/CLAUSE 8": L.UNKNOWN,
	"ARTISTIC-1.0-PERL": L.UNKNOWN,
	"ARTISTIC LICENSE 1.0 (PERL)": L.UNKNOWN,
	"ARTISTIC-2.0": L.UNKNOWN,
	"ARTISTIC LICENSE 2.0": L.UNKNOWN,
	"BLUEOAK-1.0.0": L.UNKNOWN,
	"BLUE OAK MODEL LICENSE 1.0.0": L.UNKNOWN,
	"BSD-1-CLAUSE": L.BSD,
	"BSD 1-CLAUSE LICENSE": L.BSD,
	"BSD-2-CLAUSE": L.BSD,
	'BSD 2-CLAUSE "SIMPLIFIED" LICENSE': L.BSD,
	"BSD-2-CLAUSE-PATENT": L.BSD,
	"BSD-2-CLAUSE PLUS PATENT LICENSE": L.BSD,
	"BSD-3-CLAUSE": L.BSD,
	'BSD 3-CLAUSE "NEW" OR "REVISED" LICENSE': L.BSD,
	"BSD-3-CLAUSE-LBNL": L.BSD,
	"LAWRENCE BERKELEY NATIONAL LABS BSD VARIANT LICENSE": L.BSD,
	"BSL-1.0": L.BOOST,
	"BOOST SOFTWARE LICENSE 1.0": L.BOOST,
	"CAL-1.0": L.UNKNOWN,
	"CRYPTOGRAPHIC AUTONOMY LICENSE 1.0": L.UNKNOWN,
	"CAL-1.0-COMBINED-WORK-EXCEPTION": L.UNKNOWN,
	"CRYPTOGRAPHIC AUTONOMY LICENSE 1.0 (COMBINED WORK EXCEPTION)": L.UNKNOWN,
	"CATOSL-1.1": L.UNKNOWN,
	"COMPUTER ASSOCIATES TRUSTED OPEN SOURCE LICENSE 1.1": L.UNKNOWN,
	"CDDL-1.0": L.UNKNOWN,
	"COMMON DEVELOPMENT AND DISTRIBUTION LICENSE 1.0": L.UNKNOWN,
	"CECILL-2.1": L.UNKNOWN,
	"CECILL FREE SOFTWARE LICENSE AGREEMENT V2.1": L.UNKNOWN,
	"CERN-OHL-P-2.0": L.CERN,
	"CERN OPEN HARDWARE LICENCE VERSION 2 - PERMISSIVE": L.CERN,
	"CERN-OHL-S-2.0": L.CERN,
	"CERN OPEN HARDWARE LICENCE VERSION 2 - STRONGLY RECIPROCAL": L.CERN,
	"CERN-OHL-W-2.0": L.CERN,
	"CERN OPEN HARDWARE LICENCE VERSION 2 - WEAKLY RECIPROCAL": L.CERN,
	"CNRI-PYTHON": L.CNRI,
	"CNRI PYTHON LICENSE": L.CNRI,
	"CPAL-1.0": L.COMMON,
	"COMMON PUBLIC ATTRIBUTION LICENSE 1.0": L.COMMON,
	"CPL-1.0": L.COMMON,
	"COMMON PUBLIC LICENSE 1.0": L.COMMON,
	"CUA-OPL-1.0": L.CUA,
	"CUA OFFICE PUBLIC LICENSE V1.0": L.CUA,
	"ECL-1.0": L.EDUCATIONAL,
	"EDUCATIONAL COMMUNITY LICENSE V1.0": L.EDUCATIONAL,
	"ECL-2.0": L.EDUCATIONAL,
	"EDUCATIONAL COMMUNITY LICENSE V2.0": L.EDUCATIONAL,
	"EFL-1.0": L.EIFFEL,
	"EIFFEL FORUM LICENSE V1.0": L.EIFFEL,
	"EFL-2.0": L.EIFFEL,
	"EIFFEL FORUM LICENSE V2.0": L.EIFFEL,
	"ENTESSA": L.ENTESSA,
	"ENTESSA PUBLIC LICENSE V1.0": L.ENTESSA,
	"EPL-1.0": L.ECLIPSE,
	"ECLIPSE PUBLIC LICENSE 1.0": L.ECLIPSE,
	"EPL-2.0": L.ECLIPSE,
	"ECLIPSE PUBLIC LICENSE 2.0": L.ECLIPSE,
	"EUDATAGRID": L.EU,
	"EU DATAGRID SOFTWARE LICENSE": L.EU,
	"EUPL-1.1": L.EUROPEAN,
	"EUROPEAN UNION PUBLIC LICENSE 1.1": L.EUROPEAN,
	"EUPL-1.2": L.EUROPEAN,
	"EUROPEAN UNION PUBLIC LICENSE 1.2": L.EUROPEAN,
	"FAIR": L.FAIR,
	"FAIR LICENSE": L.FAIR,
	"FRAMEWORX-1.0": L.FRAMEWORX,
	"FRAMEWORX OPEN LICENSE 1.0": L.FRAMEWORX,
	"GPL-2.0": L.GNU,
	"GNU GENERAL PUBLIC LICENSE V2.0 ONLY": L.GNU,
	"GPL-2.0+": L.GNU,
	"GNU GENERAL PUBLIC LICENSE V2.0 OR LATER": L.GNU,
	"GPL-2.0-ONLY": L.GNU,
	"GPL-2.0-OR-LATER": L.GNU,
	"GPL-3.0": L.GNU,
	"GNU GENERAL PUBLIC LICENSE V3.0 ONLY": L.GNU,
	"GPL-3.0+": L.GNU,
	"GNU GENERAL PUBLIC LICENSE V3.0 OR LATER": L.GNU,
	"GPL-3.0-ONLY": L.GNU,
	"GPL-3.0-OR-LATER": L.GNU,
	"GPL-3.0-WITH-GCC-EXCEPTION": L.GNU,
	"GNU GENERAL PUBLIC LICENSE V3.0 W/GCC RUNTIME LIBRARY EXCEPTION": L.GNU,
	"HPND": L.HISTORICAL,
	"HISTORICAL PERMISSION NOTICE AND DISCLAIMER": L.HISTORICAL,
	"ICU": L.ICU,
	"ICU LICENSE": L.ICU,
	"INTEL": L.INTEL,
	"INTEL OPEN SOURCE LICENSE": L.INTEL,
	"IPA": L.IPA,
	"IPA FONT LICENSE": L.IPA,
	"IPL-1.0": L.IBM,
	"IBM PUBLIC LICENSE V1.0": L.IBM,
	"ISC": L.ISC,
	"ISC LICENSE": L.ISC,
	"JAM": L.JAM,
	"JAM LICENSE": L.JAM,
	"LGPL-2.0": L.GNU,
	"GNU LIBRARY GENERAL PUBLIC LICENSE V2 ONLY": L.GNU,
	"LGPL-2.0+": L.GNU,
	"GNU LIBRARY GENERAL PUBLIC LICENSE V2 OR LATER": L.GNU,
	"LGPL-2.0-ONLY": L.GNU,
	"LGPL-2.0-OR-LATER": L.GNU,
	"LGPL-2.1": L.GNU,
	"GNU LESSER GENERAL PUBLIC LICENSE V2.1 ONLY": L.GNU,
	"LGPL-2.1+": L.GNU,
	"GNU LESSER GENERAL PUBLIC LICENSE V2.1 OR LATER": L.GNU,
	"LGPL-2.1-ONLY": L.GNU,
	"LGPL-2.1-OR-LATER": L.GNU,
	"LGPL-3.0": L.GNU,
	"GNU LESSER GENERAL PUBLIC LICENSE V3.0 ONLY": L.GNU,
	"LGPL-3.0+": L.GNU,
	"GNU LESSER GENERAL PUBLIC LICENSE V3.0 OR LATER": L.GNU,
	"LGPL-3.0-ONLY": L.GNU,
	"LGPL-3.0-OR-LATER": L.GNU,
	"LILIQ-P-1.1": L.LICENCE,
	"LICENCE LIBRE DU QU╔BEC û PERMISSIVE VERSION 1.1": L.LICENCE,
	"LILIQ-R-1.1": L.LICENCE,
	"LICENCE LIBRE DU QU╔BEC û R╔CIPROCIT╔ VERSION 1.1": L.LICENCE,
	"LILIQ-RPLUS-1.1": L.LICENCE,
	"LICENCE LIBRE DU QU╔BEC û R╔CIPROCIT╔ FORTE VERSION 1.1": L.LICENCE,
	"LPL-1.0": L.LUCENT,
	"LUCENT PUBLIC LICENSE VERSION 1.0": L.LUCENT,
	"LPL-1.02": L.LUCENT,
	"LUCENT PUBLIC LICENSE V1.02": L.LUCENT,
	"LPPL-1.3C": L.LATEX,
	"LATEX PROJECT PUBLIC LICENSE V1.3C": L.LATEX,
	"MIROS": L.THE,
	"THE MIROS LICENCE": L.THE,
	"MIT": L.MIT,
	"MIT LICENSE": L.MIT,
	"MIT-0": L.MIT,
	"MIT NO ATTRIBUTION": L.MIT,
	"MIT-MODERN-VARIANT": L.MIT,
	"MIT LICENSE MODERN VARIANT": L.MIT,
	"MOTOSOTO": L.MOTOSOTO,
	"MOTOSOTO LICENSE": L.MOTOSOTO,
	"MPL-1.0": L.MOZILLA,
	"MOZILLA PUBLIC LICENSE 1.0": L.MOZILLA,
	"MPL-1.1": L.MOZILLA,
	"MOZILLA PUBLIC LICENSE 1.1": L.MOZILLA,
	"MPL-2.0": L.MOZILLA,
	"MOZILLA PUBLIC LICENSE 2.0": L.MOZILLA,
	"MPL-2.0-NO-COPYLEFT-EXCEPTION": L.MOZILLA,
	"MOZILLA PUBLIC LICENSE 2.0 (NO COPYLEFT EXCEPTION)": L.MOZILLA,
	"MS-PL": L.MICROSOFT,
	"MICROSOFT PUBLIC LICENSE": L.MICROSOFT,
	"MS-RL": L.MICROSOFT,
	"MICROSOFT RECIPROCAL LICENSE": L.MICROSOFT,
	"MULANPSL-2.0": L.MULAN,
	"MULAN PERMISSIVE SOFTWARE LICENSE, VERSION 2": L.MULAN,
	"MULTICS": L.MULTICS,
	"MULTICS LICENSE": L.MULTICS,
	"NASA-1.3": L.NASA,
	"NASA OPEN SOURCE AGREEMENT 1.3": L.NASA,
	"NAUMEN": L.NAUMEN,
	"NAUMEN PUBLIC LICENSE": L.NAUMEN,
	"NCSA": L.UNIVERSITY,
	"UNIVERSITY OF ILLINOIS/NCSA OPEN SOURCE LICENSE": L.UNIVERSITY,
	"NGPL": L.NETHACK,
	"NETHACK GENERAL PUBLIC LICENSE": L.NETHACK,
	"NOKIA": L.NOKIA,
	"NOKIA OPEN SOURCE LICENSE": L.NOKIA,
	"NPOSL-3.0": L.NON-PROFIT,
	"NON-PROFIT OPEN SOFTWARE LICENSE 3.0": L.NON-PROFIT,
	"NTP": L.NTP,
	"NTP LICENSE": L.NTP,
	"OCLC-2.0": L.OCLC,
	"OCLC RESEARCH PUBLIC LICENSE 2.0": L.OCLC,
	"OFL-1.1": L.SIL,
	"SIL OPEN FONT LICENSE 1.1": L.SIL,
	"OFL-1.1-NO-RFN": L.SIL,
	"SIL OPEN FONT LICENSE 1.1 WITH NO RESERVED FONT NAME": L.SIL,
	"OFL-1.1-RFN": L.SIL,
	"SIL OPEN FONT LICENSE 1.1 WITH RESERVED FONT NAME": L.SIL,
	"OGTSL": L.OPEN,
	"OPEN GROUP TEST SUITE LICENSE": L.OPEN,
	"OLDAP-2.8": L.OPEN,
	"OPEN LDAP PUBLIC LICENSE V2.8": L.OPEN,
	"OLFL-1.3": L.OPEN,
	"OPEN LOGISTICS FOUNDATION LICENSE VERSION 1.3": L.OPEN,
	"OSET-PL-2.1": L.OSET,
	"OSET PUBLIC LICENSE VERSION 2.1": L.OSET,
	"OSL-1.0": L.OPEN,
	"OPEN SOFTWARE LICENSE 1.0": L.OPEN,
	"OSL-2.0": L.OPEN,
	"OPEN SOFTWARE LICENSE 2.0": L.OPEN,
	"OSL-2.1": L.OPEN,
	"OPEN SOFTWARE LICENSE 2.1": L.OPEN,
	"OSL-3.0": L.OPEN,
	"OPEN SOFTWARE LICENSE 3.0": L.OPEN,
	"PHP-3.0": L.PHP,
	"PHP LICENSE V3.0": L.PHP,
	"PHP-3.01": L.PHP,
	"PHP LICENSE V3.01": L.PHP,
	"POSTGRESQL": L.POSTGRESQL,
	"POSTGRESQL LICENSE": L.POSTGRESQL,
	"PYTHON-2.0": L.PYTHON,
	"PYTHON LICENSE 2.0": L.PYTHON,
	"QPL-1.0": L.Q,
	"Q PUBLIC LICENSE 1.0": L.Q,
	"RPL-1.1": L.RECIPROCAL,
	"RECIPROCAL PUBLIC LICENSE 1.1": L.RECIPROCAL,
	"RPL-1.5": L.RECIPROCAL,
	"RECIPROCAL PUBLIC LICENSE 1.5": L.RECIPROCAL,
	"RPSL-1.0": L.REALNETWORKS,
	"REALNETWORKS PUBLIC SOURCE LICENSE V1.0": L.REALNETWORKS,
	"RSCPL": L.RICOH,
	"RICOH SOURCE CODE PUBLIC LICENSE": L.RICOH,
	"SIMPL-2.0": L.SIMPLE,
	"SIMPLE PUBLIC LICENSE 2.0": L.SIMPLE,
	"SISSL": L.SUN,
	"SUN INDUSTRY STANDARDS SOURCE LICENSE V1.1": L.SUN,
	"SLEEPYCAT": L.SLEEPYCAT,
	"SLEEPYCAT LICENSE": L.SLEEPYCAT,
	"SPL-1.0": L.SUN,
	"SUN PUBLIC LICENSE V1.0": L.SUN,
	"UCL-1.0": L.UPSTREAM,
	"UPSTREAM COMPATIBILITY LICENSE V1.0": L.UPSTREAM,
	"UNICODE-3.0": L.UNICODE,
	"UNICODE LICENSE V3": L.UNICODE,
	"UNICODE-DFS-2016": L.UNICODE,
	"UNICODE LICENSE AGREEMENT - DATA FILES AND SOFTWARE (2016)": L.UNICODE,
	"UNLICENSE": L.THE,
	"THE UNLICENSE": L.THE,
	"UPL-1.0": L.UNIVERSAL,
	"UNIVERSAL PERMISSIVE LICENSE V1.0": L.UNIVERSAL,
	"VSL-1.0": L.VOVIDA,
	"VOVIDA SOFTWARE LICENSE V1.0": L.VOVIDA,
	"W3C": L.W3C,
	"W3C SOFTWARE NOTICE AND LICENSE (2002-12-31)": L.W3C,
	"W3C-20150513": L.W3C,
	"W3C SOFTWARE NOTICE AND DOCUMENT LICENSE (2015-05-13)": L.W3C,
	"WATCOM-1.0": L.SYBASE,
	"SYBASE OPEN WATCOM PUBLIC LICENSE 1.0": L.SYBASE,
	"WXWINDOWS": L.WXWINDOWS,
	"WXWINDOWS LIBRARY LICENSE": L.WXWINDOWS,
	"XNET": L.X.NET,
	"X.NET LICENSE": L.X.NET,
	"ZLIB": L.ZLIB,
	"ZLIB LICENSE": L.ZLIB,
	"ZPL-2.0": L.ZOPE,
	"ZOPE PUBLIC LICENSE 2.0": L.ZOPE,
	"ZPL-2.1": L.ZOPE,
	"ZOPE PUBLIC LICENSE 2.1": L.ZOPE,


}
